==> aws-cdk.assertions-1.126.0.tar.gz: package/lib/capture.d.ts <==
import { Matcher, MatchResult } from './matcher';
/**
 * (experimental) Capture values while matching templates.
 *
 * Using an instance of this class within a Matcher will capture the matching value.
 * The `as*()` APIs on the instance can be used to get the captured value.
 *
 * @experimental
 */
export declare class Capture extends Matcher {
    /**
     * (experimental) A name for the matcher.
     *
     * This is collected as part of the result and may be presented to the user.
     *
     * @experimental
     */
    readonly name: string;
    private value;
    /**
     * @experimental
     */
    constructor();
    /**
     * (experimental) Test whether a target matches the provided pattern.
     *
     * Every Matcher must implement this method.
     * This method will be invoked by the assertions framework. Do not call this method directly.
     *
     * @experimental
     */
    test(actual: any): MatchResult;
    /**
     * (experimental) Retrieve the captured value as a string.
     *
     * An error is generated if no value is captured or if the value is not a string.
     *
     * @experimental
     */
    asString(): string;
    /**
     * (experimental) Retrieve the captured value as a number.
     *
     * An error is generated if no value is captured or if the value is not a number.
     *
     * @experimental
     */
    asNumber(): number;
    /**
     * (experimental) Retrieve the captured value as a boolean.
     *
     * An error is generated if no value is captured or if the value is not a boolean.
     *
     * @experimental
     */
    asBoolean(): boolean;
    /**
     * (experimental) Retrieve the captured value as an array.
     *
     * An error is generated if no value is captured or if the value is not an array.
     *
     * @experimental
     */
    asArray(): any[];
    /**
     * (experimental) Retrieve the captured value as a JSON object.
     *
     * An error is generated if no value is captured or if the value is not an object.
     *
     * @experimental
     */
    asObject(): {
        [key: string]: any;
    };
    private checkNotNull;
    private reportIncorrectType;
}

==> aws-cdk.assertions-1.133.0.tar.gz: package/lib/capture.d.ts <==
import { Matcher, MatchResult } from './matcher';
/**
 * Capture values while matching templates.
 *
 * Using an instance of this class within a Matcher will capture the matching value.
 * The `as*()` APIs on the instance can be used to get the captured value.
 *
 * @stability stable
 */
export declare class Capture extends Matcher {
    /**
     * A name for the matcher.
     *
     * This is collected as part of the result and may be presented to the user.
     *
     * @stability stable
     */
    readonly name: string;
    private value;
    /**
     * @stability stable
     */
    constructor();
    /**
     * Test whether a target matches the provided pattern.
     *
     * Every Matcher must implement this method.
     * This method will be invoked by the assertions framework. Do not call this method directly.
     *
     * @stability stable
     */
    test(actual: any): MatchResult;
    /**
     * Retrieve the captured value as a string.
     *
     * An error is generated if no value is captured or if the value is not a string.
     *
     * @stability stable
     */
    asString(): string;
    /**
     * Retrieve the captured value as a number.
     *
     * An error is generated if no value is captured or if the value is not a number.
     *
     * @stability stable
     */
    asNumber(): number;
    /**
     * Retrieve the captured value as a boolean.
     *
     * An error is generated if no value is captured or if the value is not a boolean.
     *
     * @stability stable
     */
    asBoolean(): boolean;
    /**
     * Retrieve the captured value as an array.
     *
     * An error is generated if no value is captured or if the value is not an array.
     *
     * @stability stable
     */
    asArray(): any[];
    /**
     * Retrieve the captured value as a JSON object.
     *
     * An error is generated if no value is captured or if the value is not an object.
     *
     * @stability stable
     */
    asObject(): {
        [key: string]: any;
    };
    private checkNotNull;
    private reportIncorrectType;
}
